# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.invitation_status import InvitationStatus
import pprint
import six


class Invitation(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 email=None,
                 status=None,
                 company=None,
                 first_name=None,
                 last_name=None,
                 created_at=None,
                 job_title=None,
                 phone=None):
        # type: (string_types, string_types, InvitationStatus, string_types, string_types, string_types, datetime, string_types, string_types) -> None

        self._id = None
        self._email = None
        self._status = None
        self._company = None
        self._first_name = None
        self._last_name = None
        self._created_at = None
        self._job_title = None
        self._phone = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if email is not None:
            self.email = email
        if status is not None:
            self.status = status
        if company is not None:
            self.company = company
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if created_at is not None:
            self.created_at = created_at
        if job_title is not None:
            self.job_title = job_title
        if phone is not None:
            self.phone = phone

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'email': 'string_types',
            'status': 'InvitationStatus',
            'company': 'string_types',
            'first_name': 'string_types',
            'last_name': 'string_types',
            'created_at': 'datetime',
            'job_title': 'string_types',
            'phone': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'email': 'email',
            'status': 'status',
            'company': 'company',
            'first_name': 'firstName',
            'last_name': 'lastName',
            'created_at': 'createdAt',
            'job_title': 'jobTitle',
            'phone': 'phone'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this Invitation.


        :return: The id of this Invitation.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this Invitation.


        :param id_: The id of this Invitation.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def email(self):
        # type: () -> string_types
        """Gets the email of this Invitation.

        Email address of the tenant. (required)

        :return: The email of this Invitation.
        :rtype: string_types
        """
        return self._email

    @email.setter
    def email(self, email):
        # type: (string_types) -> None
        """Sets the email of this Invitation.

        Email address of the tenant. (required)

        :param email: The email of this Invitation.
        :type: string_types
        """

        if email is not None:
            if not isinstance(email, string_types):
                raise TypeError("Invalid type for `email`, type has to be `string_types`")

        self._email = email

    @property
    def status(self):
        # type: () -> InvitationStatus
        """Gets the status of this Invitation.


        :return: The status of this Invitation.
        :rtype: InvitationStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (InvitationStatus) -> None
        """Sets the status of this Invitation.


        :param status: The status of this Invitation.
        :type: InvitationStatus
        """

        if status is not None:
            if not isinstance(status, InvitationStatus):
                raise TypeError("Invalid type for `status`, type has to be `InvitationStatus`")

        self._status = status

    @property
    def company(self):
        # type: () -> string_types
        """Gets the company of this Invitation.


        :return: The company of this Invitation.
        :rtype: string_types
        """
        return self._company

    @company.setter
    def company(self, company):
        # type: (string_types) -> None
        """Sets the company of this Invitation.


        :param company: The company of this Invitation.
        :type: string_types
        """

        if company is not None:
            if not isinstance(company, string_types):
                raise TypeError("Invalid type for `company`, type has to be `string_types`")

        self._company = company

    @property
    def first_name(self):
        # type: () -> string_types
        """Gets the first_name of this Invitation.


        :return: The first_name of this Invitation.
        :rtype: string_types
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        # type: (string_types) -> None
        """Sets the first_name of this Invitation.


        :param first_name: The first_name of this Invitation.
        :type: string_types
        """

        if first_name is not None:
            if not isinstance(first_name, string_types):
                raise TypeError("Invalid type for `first_name`, type has to be `string_types`")

        self._first_name = first_name

    @property
    def last_name(self):
        # type: () -> string_types
        """Gets the last_name of this Invitation.


        :return: The last_name of this Invitation.
        :rtype: string_types
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        # type: (string_types) -> None
        """Sets the last_name of this Invitation.


        :param last_name: The last_name of this Invitation.
        :type: string_types
        """

        if last_name is not None:
            if not isinstance(last_name, string_types):
                raise TypeError("Invalid type for `last_name`, type has to be `string_types`")

        self._last_name = last_name

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this Invitation.

        Creation date of the invitation in UTC format

        :return: The created_at of this Invitation.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (datetime) -> None
        """Sets the created_at of this Invitation.

        Creation date of the invitation in UTC format

        :param created_at: The created_at of this Invitation.
        :type: datetime
        """

        if created_at is not None:
            if not isinstance(created_at, datetime):
                raise TypeError("Invalid type for `created_at`, type has to be `datetime`")

        self._created_at = created_at

    @property
    def job_title(self):
        # type: () -> string_types
        """Gets the job_title of this Invitation.


        :return: The job_title of this Invitation.
        :rtype: string_types
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        # type: (string_types) -> None
        """Sets the job_title of this Invitation.


        :param job_title: The job_title of this Invitation.
        :type: string_types
        """

        if job_title is not None:
            if not isinstance(job_title, string_types):
                raise TypeError("Invalid type for `job_title`, type has to be `string_types`")

        self._job_title = job_title

    @property
    def phone(self):
        # type: () -> string_types
        """Gets the phone of this Invitation.


        :return: The phone of this Invitation.
        :rtype: string_types
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        # type: (string_types) -> None
        """Sets the phone of this Invitation.


        :param phone: The phone of this Invitation.
        :type: string_types
        """

        if phone is not None:
            if not isinstance(phone, string_types):
                raise TypeError("Invalid type for `phone`, type has to be `string_types`")

        self._phone = phone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Invitation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class BroadcastTsTransportConfiguration(object):
    @poscheck_model
    def __init__(self,
                 muxrate=None,
                 stop_on_error=None,
                 prevent_empty_adaption_fields_in_video=None,
                 pat_repetition_rate_per_sec=None,
                 pmt_repetition_rate_per_sec=None,
                 variable_mux_rate=None,
                 initial_presentation_time_stamp=None,
                 initial_program_clock_reference=None):
        # type: (float, bool, bool, float, float, bool, float, float) -> None

        self._muxrate = None
        self._stop_on_error = None
        self._prevent_empty_adaption_fields_in_video = None
        self._pat_repetition_rate_per_sec = None
        self._pmt_repetition_rate_per_sec = None
        self._variable_mux_rate = None
        self._initial_presentation_time_stamp = None
        self._initial_program_clock_reference = None
        self.discriminator = None

        if muxrate is not None:
            self.muxrate = muxrate
        if stop_on_error is not None:
            self.stop_on_error = stop_on_error
        if prevent_empty_adaption_fields_in_video is not None:
            self.prevent_empty_adaption_fields_in_video = prevent_empty_adaption_fields_in_video
        if pat_repetition_rate_per_sec is not None:
            self.pat_repetition_rate_per_sec = pat_repetition_rate_per_sec
        if pmt_repetition_rate_per_sec is not None:
            self.pmt_repetition_rate_per_sec = pmt_repetition_rate_per_sec
        if variable_mux_rate is not None:
            self.variable_mux_rate = variable_mux_rate
        if initial_presentation_time_stamp is not None:
            self.initial_presentation_time_stamp = initial_presentation_time_stamp
        if initial_program_clock_reference is not None:
            self.initial_program_clock_reference = initial_program_clock_reference

    @property
    def openapi_types(self):
        types = {
            'muxrate': 'float',
            'stop_on_error': 'bool',
            'prevent_empty_adaption_fields_in_video': 'bool',
            'pat_repetition_rate_per_sec': 'float',
            'pmt_repetition_rate_per_sec': 'float',
            'variable_mux_rate': 'bool',
            'initial_presentation_time_stamp': 'float',
            'initial_program_clock_reference': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'muxrate': 'muxrate',
            'stop_on_error': 'stopOnError',
            'prevent_empty_adaption_fields_in_video': 'preventEmptyAdaptionFieldsInVideo',
            'pat_repetition_rate_per_sec': 'patRepetitionRatePerSec',
            'pmt_repetition_rate_per_sec': 'pmtRepetitionRatePerSec',
            'variable_mux_rate': 'variableMuxRate',
            'initial_presentation_time_stamp': 'initialPresentationTimeStamp',
            'initial_program_clock_reference': 'initialProgramClockReference'
        }
        return attributes

    @property
    def muxrate(self):
        # type: () -> float
        """Gets the muxrate of this BroadcastTsTransportConfiguration.

        Output rate in bps. The value zero implies to use minimal rate. The minimal rate leaves approximately 15kbps of null packets in the stream.

        :return: The muxrate of this BroadcastTsTransportConfiguration.
        :rtype: float
        """
        return self._muxrate

    @muxrate.setter
    def muxrate(self, muxrate):
        # type: (float) -> None
        """Sets the muxrate of this BroadcastTsTransportConfiguration.

        Output rate in bps. The value zero implies to use minimal rate. The minimal rate leaves approximately 15kbps of null packets in the stream.

        :param muxrate: The muxrate of this BroadcastTsTransportConfiguration.
        :type: float
        """

        if muxrate is not None:
            if muxrate is not None and muxrate > 1000000000:
                raise ValueError("Invalid value for `muxrate`, must be a value less than or equal to `1000000000`")
            if muxrate is not None and muxrate < 0:
                raise ValueError("Invalid value for `muxrate`, must be a value greater than or equal to `0`")
            if not isinstance(muxrate, (float, int)):
                raise TypeError("Invalid type for `muxrate`, type has to be `float`")

        self._muxrate = muxrate

    @property
    def stop_on_error(self):
        # type: () -> bool
        """Gets the stop_on_error of this BroadcastTsTransportConfiguration.

        Stop mux on errors. If true, implies halt multiplexing when any error is encountered. If false, errors are ignored and multiplexing continues. Note that the recovery from an error will usually result in an illegal transport stream and artifacts on a decoder.

        :return: The stop_on_error of this BroadcastTsTransportConfiguration.
        :rtype: bool
        """
        return self._stop_on_error

    @stop_on_error.setter
    def stop_on_error(self, stop_on_error):
        # type: (bool) -> None
        """Sets the stop_on_error of this BroadcastTsTransportConfiguration.

        Stop mux on errors. If true, implies halt multiplexing when any error is encountered. If false, errors are ignored and multiplexing continues. Note that the recovery from an error will usually result in an illegal transport stream and artifacts on a decoder.

        :param stop_on_error: The stop_on_error of this BroadcastTsTransportConfiguration.
        :type: bool
        """

        if stop_on_error is not None:
            if not isinstance(stop_on_error, bool):
                raise TypeError("Invalid type for `stop_on_error`, type has to be `bool`")

        self._stop_on_error = stop_on_error

    @property
    def prevent_empty_adaption_fields_in_video(self):
        # type: () -> bool
        """Gets the prevent_empty_adaption_fields_in_video of this BroadcastTsTransportConfiguration.

        If true, prevents adaptation fields with length field equal to zero in video, i.e., zero-length AF. Please note that this condition can only occur when pesAlign for the input stream is set to true.

        :return: The prevent_empty_adaption_fields_in_video of this BroadcastTsTransportConfiguration.
        :rtype: bool
        """
        return self._prevent_empty_adaption_fields_in_video

    @prevent_empty_adaption_fields_in_video.setter
    def prevent_empty_adaption_fields_in_video(self, prevent_empty_adaption_fields_in_video):
        # type: (bool) -> None
        """Sets the prevent_empty_adaption_fields_in_video of this BroadcastTsTransportConfiguration.

        If true, prevents adaptation fields with length field equal to zero in video, i.e., zero-length AF. Please note that this condition can only occur when pesAlign for the input stream is set to true.

        :param prevent_empty_adaption_fields_in_video: The prevent_empty_adaption_fields_in_video of this BroadcastTsTransportConfiguration.
        :type: bool
        """

        if prevent_empty_adaption_fields_in_video is not None:
            if not isinstance(prevent_empty_adaption_fields_in_video, bool):
                raise TypeError("Invalid type for `prevent_empty_adaption_fields_in_video`, type has to be `bool`")

        self._prevent_empty_adaption_fields_in_video = prevent_empty_adaption_fields_in_video

    @property
    def pat_repetition_rate_per_sec(self):
        # type: () -> float
        """Gets the pat_repetition_rate_per_sec of this BroadcastTsTransportConfiguration.

        Program Association Table (PAT) repetition rate per second. Number of PATs per second.

        :return: The pat_repetition_rate_per_sec of this BroadcastTsTransportConfiguration.
        :rtype: float
        """
        return self._pat_repetition_rate_per_sec

    @pat_repetition_rate_per_sec.setter
    def pat_repetition_rate_per_sec(self, pat_repetition_rate_per_sec):
        # type: (float) -> None
        """Sets the pat_repetition_rate_per_sec of this BroadcastTsTransportConfiguration.

        Program Association Table (PAT) repetition rate per second. Number of PATs per second.

        :param pat_repetition_rate_per_sec: The pat_repetition_rate_per_sec of this BroadcastTsTransportConfiguration.
        :type: float
        """

        if pat_repetition_rate_per_sec is not None:
            if pat_repetition_rate_per_sec is not None and pat_repetition_rate_per_sec > 1000:
                raise ValueError("Invalid value for `pat_repetition_rate_per_sec`, must be a value less than or equal to `1000`")
            if pat_repetition_rate_per_sec is not None and pat_repetition_rate_per_sec < 0.001:
                raise ValueError("Invalid value for `pat_repetition_rate_per_sec`, must be a value greater than or equal to `0.001`")
            if not isinstance(pat_repetition_rate_per_sec, (float, int)):
                raise TypeError("Invalid type for `pat_repetition_rate_per_sec`, type has to be `float`")

        self._pat_repetition_rate_per_sec = pat_repetition_rate_per_sec

    @property
    def pmt_repetition_rate_per_sec(self):
        # type: () -> float
        """Gets the pmt_repetition_rate_per_sec of this BroadcastTsTransportConfiguration.

        Program Map Table (PMT) repetition rate per second. Number of PMTs for each program per second.

        :return: The pmt_repetition_rate_per_sec of this BroadcastTsTransportConfiguration.
        :rtype: float
        """
        return self._pmt_repetition_rate_per_sec

    @pmt_repetition_rate_per_sec.setter
    def pmt_repetition_rate_per_sec(self, pmt_repetition_rate_per_sec):
        # type: (float) -> None
        """Sets the pmt_repetition_rate_per_sec of this BroadcastTsTransportConfiguration.

        Program Map Table (PMT) repetition rate per second. Number of PMTs for each program per second.

        :param pmt_repetition_rate_per_sec: The pmt_repetition_rate_per_sec of this BroadcastTsTransportConfiguration.
        :type: float
        """

        if pmt_repetition_rate_per_sec is not None:
            if pmt_repetition_rate_per_sec is not None and pmt_repetition_rate_per_sec > 1000:
                raise ValueError("Invalid value for `pmt_repetition_rate_per_sec`, must be a value less than or equal to `1000`")
            if pmt_repetition_rate_per_sec is not None and pmt_repetition_rate_per_sec < 0.001:
                raise ValueError("Invalid value for `pmt_repetition_rate_per_sec`, must be a value greater than or equal to `0.001`")
            if not isinstance(pmt_repetition_rate_per_sec, (float, int)):
                raise TypeError("Invalid type for `pmt_repetition_rate_per_sec`, type has to be `float`")

        self._pmt_repetition_rate_per_sec = pmt_repetition_rate_per_sec

    @property
    def variable_mux_rate(self):
        # type: () -> bool
        """Gets the variable_mux_rate of this BroadcastTsTransportConfiguration.

        When false, the output stream is created at a constant bit rate. When true, the output rate is allowed to vary from a maximum rate set by the muxrate parameter down to the minimum required to carry the stream.

        :return: The variable_mux_rate of this BroadcastTsTransportConfiguration.
        :rtype: bool
        """
        return self._variable_mux_rate

    @variable_mux_rate.setter
    def variable_mux_rate(self, variable_mux_rate):
        # type: (bool) -> None
        """Sets the variable_mux_rate of this BroadcastTsTransportConfiguration.

        When false, the output stream is created at a constant bit rate. When true, the output rate is allowed to vary from a maximum rate set by the muxrate parameter down to the minimum required to carry the stream.

        :param variable_mux_rate: The variable_mux_rate of this BroadcastTsTransportConfiguration.
        :type: bool
        """

        if variable_mux_rate is not None:
            if not isinstance(variable_mux_rate, bool):
                raise TypeError("Invalid type for `variable_mux_rate`, type has to be `bool`")

        self._variable_mux_rate = variable_mux_rate

    @property
    def initial_presentation_time_stamp(self):
        # type: () -> float
        """Gets the initial_presentation_time_stamp of this BroadcastTsTransportConfiguration.

        Presentation time stamp value for the first video frame. The timestamp is specified in the timescale of 90000

        :return: The initial_presentation_time_stamp of this BroadcastTsTransportConfiguration.
        :rtype: float
        """
        return self._initial_presentation_time_stamp

    @initial_presentation_time_stamp.setter
    def initial_presentation_time_stamp(self, initial_presentation_time_stamp):
        # type: (float) -> None
        """Sets the initial_presentation_time_stamp of this BroadcastTsTransportConfiguration.

        Presentation time stamp value for the first video frame. The timestamp is specified in the timescale of 90000

        :param initial_presentation_time_stamp: The initial_presentation_time_stamp of this BroadcastTsTransportConfiguration.
        :type: float
        """

        if initial_presentation_time_stamp is not None:
            if initial_presentation_time_stamp is not None and initial_presentation_time_stamp > 5400000:
                raise ValueError("Invalid value for `initial_presentation_time_stamp`, must be a value less than or equal to `5400000`")
            if initial_presentation_time_stamp is not None and initial_presentation_time_stamp < 0:
                raise ValueError("Invalid value for `initial_presentation_time_stamp`, must be a value greater than or equal to `0`")
            if not isinstance(initial_presentation_time_stamp, (float, int)):
                raise TypeError("Invalid type for `initial_presentation_time_stamp`, type has to be `float`")

        self._initial_presentation_time_stamp = initial_presentation_time_stamp

    @property
    def initial_program_clock_reference(self):
        # type: () -> float
        """Gets the initial_program_clock_reference of this BroadcastTsTransportConfiguration.

        Program Clock Reference value at the beginning of the first packet for the transport stream. The PCR is specified in the timescale of 90000

        :return: The initial_program_clock_reference of this BroadcastTsTransportConfiguration.
        :rtype: float
        """
        return self._initial_program_clock_reference

    @initial_program_clock_reference.setter
    def initial_program_clock_reference(self, initial_program_clock_reference):
        # type: (float) -> None
        """Sets the initial_program_clock_reference of this BroadcastTsTransportConfiguration.

        Program Clock Reference value at the beginning of the first packet for the transport stream. The PCR is specified in the timescale of 90000

        :param initial_program_clock_reference: The initial_program_clock_reference of this BroadcastTsTransportConfiguration.
        :type: float
        """

        if initial_program_clock_reference is not None:
            if initial_program_clock_reference is not None and initial_program_clock_reference > 2576980377600:
                raise ValueError("Invalid value for `initial_program_clock_reference`, must be a value less than or equal to `2576980377600`")
            if initial_program_clock_reference is not None and initial_program_clock_reference < 0:
                raise ValueError("Invalid value for `initial_program_clock_reference`, must be a value greater than or equal to `0`")
            if not isinstance(initial_program_clock_reference, (float, int)):
                raise TypeError("Invalid type for `initial_program_clock_reference`, type has to be `float`")

        self._initial_program_clock_reference = initial_program_clock_reference

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BroadcastTsTransportConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.encoding_statistics import EncodingStatistics
import pprint
import six


class EncodingStatisticsVod(EncodingStatistics):
    @poscheck_model
    def __init__(self,
                 date_=None,
                 bytes_encoded=None,
                 time_encoded=None,
                 bytes_egress=None,
                 billable_encoding_minutes=None,
                 billable_egress_bytes=None,
                 streams=None,
                 muxings=None,
                 features=None,
                 billable_transmuxing_minutes=None,
                 billable_feature_minutes=None,
                 time_enqueued=None,
                 realtime_factor=None):
        # type: (date, int, int, int, list[BillableEncodingMinutes], list[EgressInformation], list[StatisticsPerStream], list[StatisticsPerMuxing], list[BillableEncodingFeatureMinutes], float, float, int, float) -> None
        super(EncodingStatisticsVod, self).__init__(date_=date_, bytes_encoded=bytes_encoded, time_encoded=time_encoded, bytes_egress=bytes_egress, billable_encoding_minutes=billable_encoding_minutes, billable_egress_bytes=billable_egress_bytes, streams=streams, muxings=muxings, features=features, billable_transmuxing_minutes=billable_transmuxing_minutes, billable_feature_minutes=billable_feature_minutes)

        self._time_enqueued = None
        self._realtime_factor = None
        self.discriminator = None

        if time_enqueued is not None:
            self.time_enqueued = time_enqueued
        if realtime_factor is not None:
            self.realtime_factor = realtime_factor

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(EncodingStatisticsVod, self), 'openapi_types'):
            types = getattr(super(EncodingStatisticsVod, self), 'openapi_types')

        types.update({
            'time_enqueued': 'int',
            'realtime_factor': 'float'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(EncodingStatisticsVod, self), 'attribute_map'):
            attributes = getattr(super(EncodingStatisticsVod, self), 'attribute_map')

        attributes.update({
            'time_enqueued': 'timeEnqueued',
            'realtime_factor': 'realtimeFactor'
        })
        return attributes

    @property
    def time_enqueued(self):
        # type: () -> int
        """Gets the time_enqueued of this EncodingStatisticsVod.

        Time in seconds encoded for this encoding. (required)

        :return: The time_enqueued of this EncodingStatisticsVod.
        :rtype: int
        """
        return self._time_enqueued

    @time_enqueued.setter
    def time_enqueued(self, time_enqueued):
        # type: (int) -> None
        """Sets the time_enqueued of this EncodingStatisticsVod.

        Time in seconds encoded for this encoding. (required)

        :param time_enqueued: The time_enqueued of this EncodingStatisticsVod.
        :type: int
        """

        if time_enqueued is not None:
            if not isinstance(time_enqueued, int):
                raise TypeError("Invalid type for `time_enqueued`, type has to be `int`")

        self._time_enqueued = time_enqueued

    @property
    def realtime_factor(self):
        # type: () -> float
        """Gets the realtime_factor of this EncodingStatisticsVod.

        The realtime factor. (required)

        :return: The realtime_factor of this EncodingStatisticsVod.
        :rtype: float
        """
        return self._realtime_factor

    @realtime_factor.setter
    def realtime_factor(self, realtime_factor):
        # type: (float) -> None
        """Sets the realtime_factor of this EncodingStatisticsVod.

        The realtime factor. (required)

        :param realtime_factor: The realtime_factor of this EncodingStatisticsVod.
        :type: float
        """

        if realtime_factor is not None:
            if not isinstance(realtime_factor, (float, int)):
                raise TypeError("Invalid type for `realtime_factor`, type has to be `float`")

        self._realtime_factor = realtime_factor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(EncodingStatisticsVod, self), "to_dict"):
            result = super(EncodingStatisticsVod, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EncodingStatisticsVod):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class EncodingOutputPathsForOutput(object):
    @poscheck_model
    def __init__(self,
                 dash_manifests=None,
                 hls_manifests=None,
                 smooth_manifests=None):
        # type: (list[EncodingOutputPathsDashManifest], list[EncodingOutputPathsHlsManifest], list[EncodingOutputPathsSmoothManifest]) -> None

        self._dash_manifests = list()
        self._hls_manifests = list()
        self._smooth_manifests = list()
        self.discriminator = None

        if dash_manifests is not None:
            self.dash_manifests = dash_manifests
        if hls_manifests is not None:
            self.hls_manifests = hls_manifests
        if smooth_manifests is not None:
            self.smooth_manifests = smooth_manifests

    @property
    def openapi_types(self):
        types = {
            'dash_manifests': 'list[EncodingOutputPathsDashManifest]',
            'hls_manifests': 'list[EncodingOutputPathsHlsManifest]',
            'smooth_manifests': 'list[EncodingOutputPathsSmoothManifest]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'dash_manifests': 'dashManifests',
            'hls_manifests': 'hlsManifests',
            'smooth_manifests': 'smoothManifests'
        }
        return attributes

    @property
    def dash_manifests(self):
        # type: () -> list[EncodingOutputPathsDashManifest]
        """Gets the dash_manifests of this EncodingOutputPathsForOutput.

        Output paths for Dash manifests

        :return: The dash_manifests of this EncodingOutputPathsForOutput.
        :rtype: list[EncodingOutputPathsDashManifest]
        """
        return self._dash_manifests

    @dash_manifests.setter
    def dash_manifests(self, dash_manifests):
        # type: (list) -> None
        """Sets the dash_manifests of this EncodingOutputPathsForOutput.

        Output paths for Dash manifests

        :param dash_manifests: The dash_manifests of this EncodingOutputPathsForOutput.
        :type: list[EncodingOutputPathsDashManifest]
        """

        if dash_manifests is not None:
            if not isinstance(dash_manifests, list):
                raise TypeError("Invalid type for `dash_manifests`, type has to be `list[EncodingOutputPathsDashManifest]`")

        self._dash_manifests = dash_manifests

    @property
    def hls_manifests(self):
        # type: () -> list[EncodingOutputPathsHlsManifest]
        """Gets the hls_manifests of this EncodingOutputPathsForOutput.

        Output paths for HLS manifests

        :return: The hls_manifests of this EncodingOutputPathsForOutput.
        :rtype: list[EncodingOutputPathsHlsManifest]
        """
        return self._hls_manifests

    @hls_manifests.setter
    def hls_manifests(self, hls_manifests):
        # type: (list) -> None
        """Sets the hls_manifests of this EncodingOutputPathsForOutput.

        Output paths for HLS manifests

        :param hls_manifests: The hls_manifests of this EncodingOutputPathsForOutput.
        :type: list[EncodingOutputPathsHlsManifest]
        """

        if hls_manifests is not None:
            if not isinstance(hls_manifests, list):
                raise TypeError("Invalid type for `hls_manifests`, type has to be `list[EncodingOutputPathsHlsManifest]`")

        self._hls_manifests = hls_manifests

    @property
    def smooth_manifests(self):
        # type: () -> list[EncodingOutputPathsSmoothManifest]
        """Gets the smooth_manifests of this EncodingOutputPathsForOutput.

        Output paths for Smooth manifests

        :return: The smooth_manifests of this EncodingOutputPathsForOutput.
        :rtype: list[EncodingOutputPathsSmoothManifest]
        """
        return self._smooth_manifests

    @smooth_manifests.setter
    def smooth_manifests(self, smooth_manifests):
        # type: (list) -> None
        """Sets the smooth_manifests of this EncodingOutputPathsForOutput.

        Output paths for Smooth manifests

        :param smooth_manifests: The smooth_manifests of this EncodingOutputPathsForOutput.
        :type: list[EncodingOutputPathsSmoothManifest]
        """

        if smooth_manifests is not None:
            if not isinstance(smooth_manifests, list):
                raise TypeError("Invalid type for `smooth_manifests`, type has to be `list[EncodingOutputPathsSmoothManifest]`")

        self._smooth_manifests = smooth_manifests

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EncodingOutputPathsForOutput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.analytics_license_custom_data_field_labels import AnalyticsLicenseCustomDataFieldLabels
import pprint
import six


class AnalyticsVirtualLicense(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 timezone=None,
                 retention_time=None,
                 licenses=None,
                 custom_data_fields_count=None,
                 custom_data_field_labels=None,
                 plan_expired_at=None):
        # type: (string_types, string_types, string_types, string_types, list[AnalyticsVirtualLicenseLicensesListItem], int, AnalyticsLicenseCustomDataFieldLabels, datetime) -> None

        self._id = None
        self._name = None
        self._timezone = None
        self._retention_time = None
        self._licenses = list()
        self._custom_data_fields_count = None
        self._custom_data_field_labels = None
        self._plan_expired_at = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if name is not None:
            self.name = name
        if timezone is not None:
            self.timezone = timezone
        if retention_time is not None:
            self.retention_time = retention_time
        if licenses is not None:
            self.licenses = licenses
        if custom_data_fields_count is not None:
            self.custom_data_fields_count = custom_data_fields_count
        if custom_data_field_labels is not None:
            self.custom_data_field_labels = custom_data_field_labels
        if plan_expired_at is not None:
            self.plan_expired_at = plan_expired_at

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'name': 'string_types',
            'timezone': 'string_types',
            'retention_time': 'string_types',
            'licenses': 'list[AnalyticsVirtualLicenseLicensesListItem]',
            'custom_data_fields_count': 'int',
            'custom_data_field_labels': 'AnalyticsLicenseCustomDataFieldLabels',
            'plan_expired_at': 'datetime'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'name': 'name',
            'timezone': 'timezone',
            'retention_time': 'retentionTime',
            'licenses': 'licenses',
            'custom_data_fields_count': 'customDataFieldsCount',
            'custom_data_field_labels': 'customDataFieldLabels',
            'plan_expired_at': 'planExpiredAt'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this AnalyticsVirtualLicense.

        Analytics Virtual License Key/Id

        :return: The id of this AnalyticsVirtualLicense.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this AnalyticsVirtualLicense.

        Analytics Virtual License Key/Id

        :param id_: The id of this AnalyticsVirtualLicense.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this AnalyticsVirtualLicense.

        Name of the Analytics Virtual License

        :return: The name of this AnalyticsVirtualLicense.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this AnalyticsVirtualLicense.

        Name of the Analytics Virtual License

        :param name: The name of this AnalyticsVirtualLicense.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    @property
    def timezone(self):
        # type: () -> string_types
        """Gets the timezone of this AnalyticsVirtualLicense.

        The timezone of the Analytics Virtual License

        :return: The timezone of this AnalyticsVirtualLicense.
        :rtype: string_types
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        # type: (string_types) -> None
        """Sets the timezone of this AnalyticsVirtualLicense.

        The timezone of the Analytics Virtual License

        :param timezone: The timezone of this AnalyticsVirtualLicense.
        :type: string_types
        """

        if timezone is not None:
            if not isinstance(timezone, string_types):
                raise TypeError("Invalid type for `timezone`, type has to be `string_types`")

        self._timezone = timezone

    @property
    def retention_time(self):
        # type: () -> string_types
        """Gets the retention_time of this AnalyticsVirtualLicense.

        Retention time of impressions, returned as ISO 8601 duration format: P(n)Y(n)M(n)DT(n)H(n)M(n)S

        :return: The retention_time of this AnalyticsVirtualLicense.
        :rtype: string_types
        """
        return self._retention_time

    @retention_time.setter
    def retention_time(self, retention_time):
        # type: (string_types) -> None
        """Sets the retention_time of this AnalyticsVirtualLicense.

        Retention time of impressions, returned as ISO 8601 duration format: P(n)Y(n)M(n)DT(n)H(n)M(n)S

        :param retention_time: The retention_time of this AnalyticsVirtualLicense.
        :type: string_types
        """

        if retention_time is not None:
            if not isinstance(retention_time, string_types):
                raise TypeError("Invalid type for `retention_time`, type has to be `string_types`")

        self._retention_time = retention_time

    @property
    def licenses(self):
        # type: () -> list[AnalyticsVirtualLicenseLicensesListItem]
        """Gets the licenses of this AnalyticsVirtualLicense.

        List of Analytics Licenses

        :return: The licenses of this AnalyticsVirtualLicense.
        :rtype: list[AnalyticsVirtualLicenseLicensesListItem]
        """
        return self._licenses

    @licenses.setter
    def licenses(self, licenses):
        # type: (list) -> None
        """Sets the licenses of this AnalyticsVirtualLicense.

        List of Analytics Licenses

        :param licenses: The licenses of this AnalyticsVirtualLicense.
        :type: list[AnalyticsVirtualLicenseLicensesListItem]
        """

        if licenses is not None:
            if not isinstance(licenses, list):
                raise TypeError("Invalid type for `licenses`, type has to be `list[AnalyticsVirtualLicenseLicensesListItem]`")

        self._licenses = licenses

    @property
    def custom_data_fields_count(self):
        # type: () -> int
        """Gets the custom_data_fields_count of this AnalyticsVirtualLicense.

        The number of customData fields available

        :return: The custom_data_fields_count of this AnalyticsVirtualLicense.
        :rtype: int
        """
        return self._custom_data_fields_count

    @custom_data_fields_count.setter
    def custom_data_fields_count(self, custom_data_fields_count):
        # type: (int) -> None
        """Sets the custom_data_fields_count of this AnalyticsVirtualLicense.

        The number of customData fields available

        :param custom_data_fields_count: The custom_data_fields_count of this AnalyticsVirtualLicense.
        :type: int
        """

        if custom_data_fields_count is not None:
            if not isinstance(custom_data_fields_count, int):
                raise TypeError("Invalid type for `custom_data_fields_count`, type has to be `int`")

        self._custom_data_fields_count = custom_data_fields_count

    @property
    def custom_data_field_labels(self):
        # type: () -> AnalyticsLicenseCustomDataFieldLabels
        """Gets the custom_data_field_labels of this AnalyticsVirtualLicense.

        Labels for Custom Data fields

        :return: The custom_data_field_labels of this AnalyticsVirtualLicense.
        :rtype: AnalyticsLicenseCustomDataFieldLabels
        """
        return self._custom_data_field_labels

    @custom_data_field_labels.setter
    def custom_data_field_labels(self, custom_data_field_labels):
        # type: (AnalyticsLicenseCustomDataFieldLabels) -> None
        """Sets the custom_data_field_labels of this AnalyticsVirtualLicense.

        Labels for Custom Data fields

        :param custom_data_field_labels: The custom_data_field_labels of this AnalyticsVirtualLicense.
        :type: AnalyticsLicenseCustomDataFieldLabels
        """

        if custom_data_field_labels is not None:
            if not isinstance(custom_data_field_labels, AnalyticsLicenseCustomDataFieldLabels):
                raise TypeError("Invalid type for `custom_data_field_labels`, type has to be `AnalyticsLicenseCustomDataFieldLabels`")

        self._custom_data_field_labels = custom_data_field_labels

    @property
    def plan_expired_at(self):
        # type: () -> datetime
        """Gets the plan_expired_at of this AnalyticsVirtualLicense.

        The expiration date of the license if applicable, returned as ISO 8601 date-time format

        :return: The plan_expired_at of this AnalyticsVirtualLicense.
        :rtype: datetime
        """
        return self._plan_expired_at

    @plan_expired_at.setter
    def plan_expired_at(self, plan_expired_at):
        # type: (datetime) -> None
        """Sets the plan_expired_at of this AnalyticsVirtualLicense.

        The expiration date of the license if applicable, returned as ISO 8601 date-time format

        :param plan_expired_at: The plan_expired_at of this AnalyticsVirtualLicense.
        :type: datetime
        """

        if plan_expired_at is not None:
            if not isinstance(plan_expired_at, datetime):
                raise TypeError("Invalid type for `plan_expired_at`, type has to be `datetime`")

        self._plan_expired_at = plan_expired_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsVirtualLicense):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.time_based_trimming_input_stream import TimeBasedTrimmingInputStream
from bitmovin_api_sdk.encoding.encodings.input_streams.trimming.time_based.time_based_trimming_input_stream_list_query_params import TimeBasedTrimmingInputStreamListQueryParams


class TimeBasedApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(TimeBasedApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, time_based_trimming_input_stream, **kwargs):
        # type: (string_types, TimeBasedTrimmingInputStream, dict) -> TimeBasedTrimmingInputStream
        """Add Time-Based Trimming Input Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param time_based_trimming_input_stream: The Time-Based Trimming Input Stream to be created
        :type time_based_trimming_input_stream: TimeBasedTrimmingInputStream, required
        :return: Time-Based Trimming Input Stream
        :rtype: TimeBasedTrimmingInputStream
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/input-streams/trimming/time-based',
            time_based_trimming_input_stream,
            path_params={'encoding_id': encoding_id},
            type=TimeBasedTrimmingInputStream,
            **kwargs
        )

    def delete(self, encoding_id, input_stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Time-Based Trimming Input Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param input_stream_id: Id of the Time-Based Trimming Input Stream.
        :type input_stream_id: string_types, required
        :return: Id of the Time-Based Trimming Input Stream
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/input-streams/trimming/time-based/{input_stream_id}',
            path_params={'encoding_id': encoding_id, 'input_stream_id': input_stream_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, input_stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> TimeBasedTrimmingInputStream
        """Time-Based Trimming Input Stream Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param input_stream_id: Id of the Time-Based Trimming Input Stream.
        :type input_stream_id: string_types, required
        :return: Stream
        :rtype: TimeBasedTrimmingInputStream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/input-streams/trimming/time-based/{input_stream_id}',
            path_params={'encoding_id': encoding_id, 'input_stream_id': input_stream_id},
            type=TimeBasedTrimmingInputStream,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, TimeBasedTrimmingInputStreamListQueryParams, dict) -> TimeBasedTrimmingInputStream
        """List Time-Based Trimming Input Streams

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: TimeBasedTrimmingInputStreamListQueryParams
        :return: List of Time-Based Trimming Input Streams
        :rtype: TimeBasedTrimmingInputStream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/input-streams/trimming/time-based',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=TimeBasedTrimmingInputStream,
            **kwargs
        )



from bitmovin_api_sdk.encoding.encodings.muxings.webm.webm_api import WebmApi
from bitmovin_api_sdk.encoding.encodings.muxings.webm.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.webm.drm.drm_api import DrmApi
from bitmovin_api_sdk.encoding.encodings.muxings.webm.webm_muxing_list_query_params import WebmMuxingListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.marketplace import Marketplace
import pprint
import six


class AccountInformation(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 email=None,
                 api_keys=None,
                 first_name=None,
                 last_name=None,
                 phone=None,
                 company=None,
                 verified=None,
                 marketplace=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, list[AccountApiKey], string_types, string_types, string_types, string_types, bool, Marketplace) -> None
        super(AccountInformation, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._email = None
        self._api_keys = list()
        self._first_name = None
        self._last_name = None
        self._phone = None
        self._company = None
        self._verified = None
        self._marketplace = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if api_keys is not None:
            self.api_keys = api_keys
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if phone is not None:
            self.phone = phone
        if company is not None:
            self.company = company
        if verified is not None:
            self.verified = verified
        if marketplace is not None:
            self.marketplace = marketplace

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AccountInformation, self), 'openapi_types'):
            types = getattr(super(AccountInformation, self), 'openapi_types')

        types.update({
            'email': 'string_types',
            'api_keys': 'list[AccountApiKey]',
            'first_name': 'string_types',
            'last_name': 'string_types',
            'phone': 'string_types',
            'company': 'string_types',
            'verified': 'bool',
            'marketplace': 'Marketplace'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AccountInformation, self), 'attribute_map'):
            attributes = getattr(super(AccountInformation, self), 'attribute_map')

        attributes.update({
            'email': 'email',
            'api_keys': 'apiKeys',
            'first_name': 'firstName',
            'last_name': 'lastName',
            'phone': 'phone',
            'company': 'company',
            'verified': 'verified',
            'marketplace': 'marketplace'
        })
        return attributes

    @property
    def email(self):
        # type: () -> string_types
        """Gets the email of this AccountInformation.

        Email address of the account. (required)

        :return: The email of this AccountInformation.
        :rtype: string_types
        """
        return self._email

    @email.setter
    def email(self, email):
        # type: (string_types) -> None
        """Sets the email of this AccountInformation.

        Email address of the account. (required)

        :param email: The email of this AccountInformation.
        :type: string_types
        """

        if email is not None:
            if not isinstance(email, string_types):
                raise TypeError("Invalid type for `email`, type has to be `string_types`")

        self._email = email

    @property
    def api_keys(self):
        # type: () -> list[AccountApiKey]
        """Gets the api_keys of this AccountInformation.

        ApiKeys associated with the account (required)

        :return: The api_keys of this AccountInformation.
        :rtype: list[AccountApiKey]
        """
        return self._api_keys

    @api_keys.setter
    def api_keys(self, api_keys):
        # type: (list) -> None
        """Sets the api_keys of this AccountInformation.

        ApiKeys associated with the account (required)

        :param api_keys: The api_keys of this AccountInformation.
        :type: list[AccountApiKey]
        """

        if api_keys is not None:
            if not isinstance(api_keys, list):
                raise TypeError("Invalid type for `api_keys`, type has to be `list[AccountApiKey]`")

        self._api_keys = api_keys

    @property
    def first_name(self):
        # type: () -> string_types
        """Gets the first_name of this AccountInformation.

        First name of the tenant.

        :return: The first_name of this AccountInformation.
        :rtype: string_types
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        # type: (string_types) -> None
        """Sets the first_name of this AccountInformation.

        First name of the tenant.

        :param first_name: The first_name of this AccountInformation.
        :type: string_types
        """

        if first_name is not None:
            if not isinstance(first_name, string_types):
                raise TypeError("Invalid type for `first_name`, type has to be `string_types`")

        self._first_name = first_name

    @property
    def last_name(self):
        # type: () -> string_types
        """Gets the last_name of this AccountInformation.

        Last name of the tenant.

        :return: The last_name of this AccountInformation.
        :rtype: string_types
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        # type: (string_types) -> None
        """Sets the last_name of this AccountInformation.

        Last name of the tenant.

        :param last_name: The last_name of this AccountInformation.
        :type: string_types
        """

        if last_name is not None:
            if not isinstance(last_name, string_types):
                raise TypeError("Invalid type for `last_name`, type has to be `string_types`")

        self._last_name = last_name

    @property
    def phone(self):
        # type: () -> string_types
        """Gets the phone of this AccountInformation.

        Phone number of the tenant.

        :return: The phone of this AccountInformation.
        :rtype: string_types
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        # type: (string_types) -> None
        """Sets the phone of this AccountInformation.

        Phone number of the tenant.

        :param phone: The phone of this AccountInformation.
        :type: string_types
        """

        if phone is not None:
            if not isinstance(phone, string_types):
                raise TypeError("Invalid type for `phone`, type has to be `string_types`")

        self._phone = phone

    @property
    def company(self):
        # type: () -> string_types
        """Gets the company of this AccountInformation.

        Company name of the tenant.

        :return: The company of this AccountInformation.
        :rtype: string_types
        """
        return self._company

    @company.setter
    def company(self, company):
        # type: (string_types) -> None
        """Sets the company of this AccountInformation.

        Company name of the tenant.

        :param company: The company of this AccountInformation.
        :type: string_types
        """

        if company is not None:
            if not isinstance(company, string_types):
                raise TypeError("Invalid type for `company`, type has to be `string_types`")

        self._company = company

    @property
    def verified(self):
        # type: () -> bool
        """Gets the verified of this AccountInformation.


        :return: The verified of this AccountInformation.
        :rtype: bool
        """
        return self._verified

    @verified.setter
    def verified(self, verified):
        # type: (bool) -> None
        """Sets the verified of this AccountInformation.


        :param verified: The verified of this AccountInformation.
        :type: bool
        """

        if verified is not None:
            if not isinstance(verified, bool):
                raise TypeError("Invalid type for `verified`, type has to be `bool`")

        self._verified = verified

    @property
    def marketplace(self):
        # type: () -> Marketplace
        """Gets the marketplace of this AccountInformation.


        :return: The marketplace of this AccountInformation.
        :rtype: Marketplace
        """
        return self._marketplace

    @marketplace.setter
    def marketplace(self, marketplace):
        # type: (Marketplace) -> None
        """Sets the marketplace of this AccountInformation.


        :param marketplace: The marketplace of this AccountInformation.
        :type: Marketplace
        """

        if marketplace is not None:
            if not isinstance(marketplace, Marketplace):
                raise TypeError("Invalid type for `marketplace`, type has to be `Marketplace`")

        self._marketplace = marketplace

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AccountInformation, self), "to_dict"):
            result = super(AccountInformation, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.google_cloud_region import GoogleCloudRegion
from bitmovin_api_sdk.models.input import Input
import pprint
import six


class GcsInput(Input):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 bucket_name=None,
                 cloud_region=None,
                 access_key=None,
                 secret_key=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, GoogleCloudRegion, string_types, string_types) -> None
        super(GcsInput, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._bucket_name = None
        self._cloud_region = None
        self._access_key = None
        self._secret_key = None
        self.discriminator = None

        if bucket_name is not None:
            self.bucket_name = bucket_name
        if cloud_region is not None:
            self.cloud_region = cloud_region
        if access_key is not None:
            self.access_key = access_key
        if secret_key is not None:
            self.secret_key = secret_key

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(GcsInput, self), 'openapi_types'):
            types = getattr(super(GcsInput, self), 'openapi_types')

        types.update({
            'bucket_name': 'string_types',
            'cloud_region': 'GoogleCloudRegion',
            'access_key': 'string_types',
            'secret_key': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(GcsInput, self), 'attribute_map'):
            attributes = getattr(super(GcsInput, self), 'attribute_map')

        attributes.update({
            'bucket_name': 'bucketName',
            'cloud_region': 'cloudRegion',
            'access_key': 'accessKey',
            'secret_key': 'secretKey'
        })
        return attributes

    @property
    def bucket_name(self):
        # type: () -> string_types
        """Gets the bucket_name of this GcsInput.

        Name of the bucket (required)

        :return: The bucket_name of this GcsInput.
        :rtype: string_types
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        # type: (string_types) -> None
        """Sets the bucket_name of this GcsInput.

        Name of the bucket (required)

        :param bucket_name: The bucket_name of this GcsInput.
        :type: string_types
        """

        if bucket_name is not None:
            if not isinstance(bucket_name, string_types):
                raise TypeError("Invalid type for `bucket_name`, type has to be `string_types`")

        self._bucket_name = bucket_name

    @property
    def cloud_region(self):
        # type: () -> GoogleCloudRegion
        """Gets the cloud_region of this GcsInput.

        The cloud region in which the bucket is located. Is used to determine the ideal location for your encodings automatically.

        :return: The cloud_region of this GcsInput.
        :rtype: GoogleCloudRegion
        """
        return self._cloud_region

    @cloud_region.setter
    def cloud_region(self, cloud_region):
        # type: (GoogleCloudRegion) -> None
        """Sets the cloud_region of this GcsInput.

        The cloud region in which the bucket is located. Is used to determine the ideal location for your encodings automatically.

        :param cloud_region: The cloud_region of this GcsInput.
        :type: GoogleCloudRegion
        """

        if cloud_region is not None:
            if not isinstance(cloud_region, GoogleCloudRegion):
                raise TypeError("Invalid type for `cloud_region`, type has to be `GoogleCloudRegion`")

        self._cloud_region = cloud_region

    @property
    def access_key(self):
        # type: () -> string_types
        """Gets the access_key of this GcsInput.

        GCS access key (required)

        :return: The access_key of this GcsInput.
        :rtype: string_types
        """
        return self._access_key

    @access_key.setter
    def access_key(self, access_key):
        # type: (string_types) -> None
        """Sets the access_key of this GcsInput.

        GCS access key (required)

        :param access_key: The access_key of this GcsInput.
        :type: string_types
        """

        if access_key is not None:
            if not isinstance(access_key, string_types):
                raise TypeError("Invalid type for `access_key`, type has to be `string_types`")

        self._access_key = access_key

    @property
    def secret_key(self):
        # type: () -> string_types
        """Gets the secret_key of this GcsInput.

        GCS secret key (required)

        :return: The secret_key of this GcsInput.
        :rtype: string_types
        """
        return self._secret_key

    @secret_key.setter
    def secret_key(self, secret_key):
        # type: (string_types) -> None
        """Sets the secret_key of this GcsInput.

        GCS secret key (required)

        :param secret_key: The secret_key of this GcsInput.
        :type: string_types
        """

        if secret_key is not None:
            if not isinstance(secret_key, string_types):
                raise TypeError("Invalid type for `secret_key`, type has to be `string_types`")

        self._secret_key = secret_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(GcsInput, self), "to_dict"):
            result = super(GcsInput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GcsInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.muxing import Muxing
from bitmovin_api_sdk.models.pts_align_mode import PTSAlignMode
from bitmovin_api_sdk.models.stream_conditions_mode import StreamConditionsMode
import pprint
import six


class Fmp4Muxing(Muxing):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 streams=None,
                 outputs=None,
                 avg_bitrate=None,
                 min_bitrate=None,
                 max_bitrate=None,
                 ignored_by=None,
                 stream_conditions_mode=None,
                 segment_length=None,
                 segment_naming=None,
                 segment_naming_template=None,
                 init_segment_name=None,
                 init_segment_name_template=None,
                 write_duration_per_sample=None,
                 segments_muxed=None,
                 pts_align_mode=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[MuxingStream], list[EncodingOutput], int, int, int, list[Ignoring], StreamConditionsMode, float, string_types, string_types, string_types, string_types, bool, int, PTSAlignMode) -> None
        super(Fmp4Muxing, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, streams=streams, outputs=outputs, avg_bitrate=avg_bitrate, min_bitrate=min_bitrate, max_bitrate=max_bitrate, ignored_by=ignored_by, stream_conditions_mode=stream_conditions_mode)

        self._segment_length = None
        self._segment_naming = None
        self._segment_naming_template = None
        self._init_segment_name = None
        self._init_segment_name_template = None
        self._write_duration_per_sample = None
        self._segments_muxed = None
        self._pts_align_mode = None
        self.discriminator = None

        if segment_length is not None:
            self.segment_length = segment_length
        if segment_naming is not None:
            self.segment_naming = segment_naming
        if segment_naming_template is not None:
            self.segment_naming_template = segment_naming_template
        if init_segment_name is not None:
            self.init_segment_name = init_segment_name
        if init_segment_name_template is not None:
            self.init_segment_name_template = init_segment_name_template
        if write_duration_per_sample is not None:
            self.write_duration_per_sample = write_duration_per_sample
        if segments_muxed is not None:
            self.segments_muxed = segments_muxed
        if pts_align_mode is not None:
            self.pts_align_mode = pts_align_mode

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Fmp4Muxing, self), 'openapi_types'):
            types = getattr(super(Fmp4Muxing, self), 'openapi_types')

        types.update({
            'segment_length': 'float',
            'segment_naming': 'string_types',
            'segment_naming_template': 'string_types',
            'init_segment_name': 'string_types',
            'init_segment_name_template': 'string_types',
            'write_duration_per_sample': 'bool',
            'segments_muxed': 'int',
            'pts_align_mode': 'PTSAlignMode'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Fmp4Muxing, self), 'attribute_map'):
            attributes = getattr(super(Fmp4Muxing, self), 'attribute_map')

        attributes.update({
            'segment_length': 'segmentLength',
            'segment_naming': 'segmentNaming',
            'segment_naming_template': 'segmentNamingTemplate',
            'init_segment_name': 'initSegmentName',
            'init_segment_name_template': 'initSegmentNameTemplate',
            'write_duration_per_sample': 'writeDurationPerSample',
            'segments_muxed': 'segmentsMuxed',
            'pts_align_mode': 'ptsAlignMode'
        })
        return attributes

    @property
    def segment_length(self):
        # type: () -> float
        """Gets the segment_length of this Fmp4Muxing.

        Length of the fragments in seconds (required)

        :return: The segment_length of this Fmp4Muxing.
        :rtype: float
        """
        return self._segment_length

    @segment_length.setter
    def segment_length(self, segment_length):
        # type: (float) -> None
        """Sets the segment_length of this Fmp4Muxing.

        Length of the fragments in seconds (required)

        :param segment_length: The segment_length of this Fmp4Muxing.
        :type: float
        """

        if segment_length is not None:
            if not isinstance(segment_length, (float, int)):
                raise TypeError("Invalid type for `segment_length`, type has to be `float`")

        self._segment_length = segment_length

    @property
    def segment_naming(self):
        # type: () -> string_types
        """Gets the segment_naming of this Fmp4Muxing.

        Segment naming policy

        :return: The segment_naming of this Fmp4Muxing.
        :rtype: string_types
        """
        return self._segment_naming

    @segment_naming.setter
    def segment_naming(self, segment_naming):
        # type: (string_types) -> None
        """Sets the segment_naming of this Fmp4Muxing.

        Segment naming policy

        :param segment_naming: The segment_naming of this Fmp4Muxing.
        :type: string_types
        """

        if segment_naming is not None:
            if not isinstance(segment_naming, string_types):
                raise TypeError("Invalid type for `segment_naming`, type has to be `string_types`")

        self._segment_naming = segment_naming

    @property
    def segment_naming_template(self):
        # type: () -> string_types
        """Gets the segment_naming_template of this Fmp4Muxing.

        Segment naming policy containing a placeholder of the format '{rand_chars:x}', which will be replaced by a random alphanumeric string of length x (default 32) on each (re)start of the encoding. The resulting string will be copied to the segmentNaming property. Intended to avoid re-use of segment names after restarting a live encoding. If segmentNamingTemplate is set, segmentNaming must not be set.

        :return: The segment_naming_template of this Fmp4Muxing.
        :rtype: string_types
        """
        return self._segment_naming_template

    @segment_naming_template.setter
    def segment_naming_template(self, segment_naming_template):
        # type: (string_types) -> None
        """Sets the segment_naming_template of this Fmp4Muxing.

        Segment naming policy containing a placeholder of the format '{rand_chars:x}', which will be replaced by a random alphanumeric string of length x (default 32) on each (re)start of the encoding. The resulting string will be copied to the segmentNaming property. Intended to avoid re-use of segment names after restarting a live encoding. If segmentNamingTemplate is set, segmentNaming must not be set.

        :param segment_naming_template: The segment_naming_template of this Fmp4Muxing.
        :type: string_types
        """

        if segment_naming_template is not None:
            if not isinstance(segment_naming_template, string_types):
                raise TypeError("Invalid type for `segment_naming_template`, type has to be `string_types`")

        self._segment_naming_template = segment_naming_template

    @property
    def init_segment_name(self):
        # type: () -> string_types
        """Gets the init_segment_name of this Fmp4Muxing.

        Init segment name

        :return: The init_segment_name of this Fmp4Muxing.
        :rtype: string_types
        """
        return self._init_segment_name

    @init_segment_name.setter
    def init_segment_name(self, init_segment_name):
        # type: (string_types) -> None
        """Sets the init_segment_name of this Fmp4Muxing.

        Init segment name

        :param init_segment_name: The init_segment_name of this Fmp4Muxing.
        :type: string_types
        """

        if init_segment_name is not None:
            if not isinstance(init_segment_name, string_types):
                raise TypeError("Invalid type for `init_segment_name`, type has to be `string_types`")

        self._init_segment_name = init_segment_name

    @property
    def init_segment_name_template(self):
        # type: () -> string_types
        """Gets the init_segment_name_template of this Fmp4Muxing.

        Segment naming policy containing a placeholder of the format '{rand_chars:x}', which will be replaced by a random alphanumeric string of length x (default 32) on each (re)start of the encoding. The resulting string will be copied to the initSegmentName property. Intended to avoid re-use of segment names after restarting a live encoding. If initSegmentNameTemplate is set, initSegmentName must not be set.

        :return: The init_segment_name_template of this Fmp4Muxing.
        :rtype: string_types
        """
        return self._init_segment_name_template

    @init_segment_name_template.setter
    def init_segment_name_template(self, init_segment_name_template):
        # type: (string_types) -> None
        """Sets the init_segment_name_template of this Fmp4Muxing.

        Segment naming policy containing a placeholder of the format '{rand_chars:x}', which will be replaced by a random alphanumeric string of length x (default 32) on each (re)start of the encoding. The resulting string will be copied to the initSegmentName property. Intended to avoid re-use of segment names after restarting a live encoding. If initSegmentNameTemplate is set, initSegmentName must not be set.

        :param init_segment_name_template: The init_segment_name_template of this Fmp4Muxing.
        :type: string_types
        """

        if init_segment_name_template is not None:
            if not isinstance(init_segment_name_template, string_types):
                raise TypeError("Invalid type for `init_segment_name_template`, type has to be `string_types`")

        self._init_segment_name_template = init_segment_name_template

    @property
    def write_duration_per_sample(self):
        # type: () -> bool
        """Gets the write_duration_per_sample of this Fmp4Muxing.

        Writes the duration per sample into the sample entry in the Track Fragment Run Box. This could help to fix playback issues on legacy players. Enabling this flag increases the muxing overhead by 4 bytes per sample/frame.

        :return: The write_duration_per_sample of this Fmp4Muxing.
        :rtype: bool
        """
        return self._write_duration_per_sample

    @write_duration_per_sample.setter
    def write_duration_per_sample(self, write_duration_per_sample):
        # type: (bool) -> None
        """Sets the write_duration_per_sample of this Fmp4Muxing.

        Writes the duration per sample into the sample entry in the Track Fragment Run Box. This could help to fix playback issues on legacy players. Enabling this flag increases the muxing overhead by 4 bytes per sample/frame.

        :param write_duration_per_sample: The write_duration_per_sample of this Fmp4Muxing.
        :type: bool
        """

        if write_duration_per_sample is not None:
            if not isinstance(write_duration_per_sample, bool):
                raise TypeError("Invalid type for `write_duration_per_sample`, type has to be `bool`")

        self._write_duration_per_sample = write_duration_per_sample

    @property
    def segments_muxed(self):
        # type: () -> int
        """Gets the segments_muxed of this Fmp4Muxing.

        Number of segments which have been encoded

        :return: The segments_muxed of this Fmp4Muxing.
        :rtype: int
        """
        return self._segments_muxed

    @segments_muxed.setter
    def segments_muxed(self, segments_muxed):
        # type: (int) -> None
        """Sets the segments_muxed of this Fmp4Muxing.

        Number of segments which have been encoded

        :param segments_muxed: The segments_muxed of this Fmp4Muxing.
        :type: int
        """

        if segments_muxed is not None:
            if not isinstance(segments_muxed, int):
                raise TypeError("Invalid type for `segments_muxed`, type has to be `int`")

        self._segments_muxed = segments_muxed

    @property
    def pts_align_mode(self):
        # type: () -> PTSAlignMode
        """Gets the pts_align_mode of this Fmp4Muxing.

        Alignment mode for composition / presentation timestamps (CTS/PTS). Only applies to h.264 and h.265

        :return: The pts_align_mode of this Fmp4Muxing.
        :rtype: PTSAlignMode
        """
        return self._pts_align_mode

    @pts_align_mode.setter
    def pts_align_mode(self, pts_align_mode):
        # type: (PTSAlignMode) -> None
        """Sets the pts_align_mode of this Fmp4Muxing.

        Alignment mode for composition / presentation timestamps (CTS/PTS). Only applies to h.264 and h.265

        :param pts_align_mode: The pts_align_mode of this Fmp4Muxing.
        :type: PTSAlignMode
        """

        if pts_align_mode is not None:
            if not isinstance(pts_align_mode, PTSAlignMode):
                raise TypeError("Invalid type for `pts_align_mode`, type has to be `PTSAlignMode`")

        self._pts_align_mode = pts_align_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Fmp4Muxing, self), "to_dict"):
            result = super(Fmp4Muxing, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Fmp4Muxing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.raw.raw_api import RawApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.raw.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.raw.raw_id3_tag_list_query_params import RawId3TagListQueryParams



from bitmovin_api_sdk.encoding.outputs.akamai_msl.akamai_msl_api import AkamaiMslApi
from bitmovin_api_sdk.encoding.outputs.akamai_msl.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.outputs.akamai_msl.akamai_msl_output_list_query_params import AkamaiMslOutputListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.dolby_atmos_ingest_input_stream import DolbyAtmosIngestInputStream
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.input_streams.dolby_atmos.dolby_atmos_ingest_input_stream_list_query_params import DolbyAtmosIngestInputStreamListQueryParams


class DolbyAtmosApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DolbyAtmosApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, dolby_atmos_ingest_input_stream, **kwargs):
        # type: (string_types, DolbyAtmosIngestInputStream, dict) -> DolbyAtmosIngestInputStream
        """Add Dolby Atmos input stream

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param dolby_atmos_ingest_input_stream: The Dolby Atmos input stream to be created
        :type dolby_atmos_ingest_input_stream: DolbyAtmosIngestInputStream, required
        :return: Dolby Atmos input stream
        :rtype: DolbyAtmosIngestInputStream
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/input-streams/dolby-atmos',
            dolby_atmos_ingest_input_stream,
            path_params={'encoding_id': encoding_id},
            type=DolbyAtmosIngestInputStream,
            **kwargs
        )

    def delete(self, encoding_id, input_stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Dolby Atmos input stream

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param input_stream_id: Id of the Dolby Atmos input stream
        :type input_stream_id: string_types, required
        :return: Id of the Dolby Atmos input stream
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/input-streams/dolby-atmos/{input_stream_id}',
            path_params={'encoding_id': encoding_id, 'input_stream_id': input_stream_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, input_stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> DolbyAtmosIngestInputStream
        """Dolby Atmos input stream details

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param input_stream_id: Id of the Dolby Atmos input stream
        :type input_stream_id: string_types, required
        :return: Dolby Atmos Input Stream
        :rtype: DolbyAtmosIngestInputStream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/input-streams/dolby-atmos/{input_stream_id}',
            path_params={'encoding_id': encoding_id, 'input_stream_id': input_stream_id},
            type=DolbyAtmosIngestInputStream,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, DolbyAtmosIngestInputStreamListQueryParams, dict) -> DolbyAtmosIngestInputStream
        """List Dolby Atmos input streams

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: DolbyAtmosIngestInputStreamListQueryParams
        :return: List Dolby Atmos input streams
        :rtype: DolbyAtmosIngestInputStream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/input-streams/dolby-atmos',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=DolbyAtmosIngestInputStream,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.akamai_msl_stream_format import AkamaiMslStreamFormat
from bitmovin_api_sdk.models.akamai_msl_version import AkamaiMslVersion
from bitmovin_api_sdk.models.output import Output
import pprint
import six


class AkamaiMslOutput(Output):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 acl=None,
                 stream_id=None,
                 event_name=None,
                 stream_format=None,
                 msl_version=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[AclEntry], int, string_types, AkamaiMslStreamFormat, AkamaiMslVersion) -> None
        super(AkamaiMslOutput, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, acl=acl)

        self._stream_id = None
        self._event_name = None
        self._stream_format = None
        self._msl_version = None
        self.discriminator = None

        if stream_id is not None:
            self.stream_id = stream_id
        if event_name is not None:
            self.event_name = event_name
        if stream_format is not None:
            self.stream_format = stream_format
        if msl_version is not None:
            self.msl_version = msl_version

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AkamaiMslOutput, self), 'openapi_types'):
            types = getattr(super(AkamaiMslOutput, self), 'openapi_types')

        types.update({
            'stream_id': 'int',
            'event_name': 'string_types',
            'stream_format': 'AkamaiMslStreamFormat',
            'msl_version': 'AkamaiMslVersion'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AkamaiMslOutput, self), 'attribute_map'):
            attributes = getattr(super(AkamaiMslOutput, self), 'attribute_map')

        attributes.update({
            'stream_id': 'streamId',
            'event_name': 'eventName',
            'stream_format': 'streamFormat',
            'msl_version': 'mslVersion'
        })
        return attributes

    @property
    def stream_id(self):
        # type: () -> int
        """Gets the stream_id of this AkamaiMslOutput.

        The Akamai stream ID (required)

        :return: The stream_id of this AkamaiMslOutput.
        :rtype: int
        """
        return self._stream_id

    @stream_id.setter
    def stream_id(self, stream_id):
        # type: (int) -> None
        """Sets the stream_id of this AkamaiMslOutput.

        The Akamai stream ID (required)

        :param stream_id: The stream_id of this AkamaiMslOutput.
        :type: int
        """

        if stream_id is not None:
            if not isinstance(stream_id, int):
                raise TypeError("Invalid type for `stream_id`, type has to be `int`")

        self._stream_id = stream_id

    @property
    def event_name(self):
        # type: () -> string_types
        """Gets the event_name of this AkamaiMslOutput.

        The Akamai event name (required)

        :return: The event_name of this AkamaiMslOutput.
        :rtype: string_types
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        # type: (string_types) -> None
        """Sets the event_name of this AkamaiMslOutput.

        The Akamai event name (required)

        :param event_name: The event_name of this AkamaiMslOutput.
        :type: string_types
        """

        if event_name is not None:
            if not isinstance(event_name, string_types):
                raise TypeError("Invalid type for `event_name`, type has to be `string_types`")

        self._event_name = event_name

    @property
    def stream_format(self):
        # type: () -> AkamaiMslStreamFormat
        """Gets the stream_format of this AkamaiMslOutput.

        The stream format. Only DASH is supported at the moment. (required)

        :return: The stream_format of this AkamaiMslOutput.
        :rtype: AkamaiMslStreamFormat
        """
        return self._stream_format

    @stream_format.setter
    def stream_format(self, stream_format):
        # type: (AkamaiMslStreamFormat) -> None
        """Sets the stream_format of this AkamaiMslOutput.

        The stream format. Only DASH is supported at the moment. (required)

        :param stream_format: The stream_format of this AkamaiMslOutput.
        :type: AkamaiMslStreamFormat
        """

        if stream_format is not None:
            if not isinstance(stream_format, AkamaiMslStreamFormat):
                raise TypeError("Invalid type for `stream_format`, type has to be `AkamaiMslStreamFormat`")

        self._stream_format = stream_format

    @property
    def msl_version(self):
        # type: () -> AkamaiMslVersion
        """Gets the msl_version of this AkamaiMslOutput.

        The Akamai MSL Version. Only MSL4 is supported at the moment. (required)

        :return: The msl_version of this AkamaiMslOutput.
        :rtype: AkamaiMslVersion
        """
        return self._msl_version

    @msl_version.setter
    def msl_version(self, msl_version):
        # type: (AkamaiMslVersion) -> None
        """Sets the msl_version of this AkamaiMslOutput.

        The Akamai MSL Version. Only MSL4 is supported at the moment. (required)

        :param msl_version: The msl_version of this AkamaiMslOutput.
        :type: AkamaiMslVersion
        """

        if msl_version is not None:
            if not isinstance(msl_version, AkamaiMslVersion):
                raise TypeError("Invalid type for `msl_version`, type has to be `AkamaiMslVersion`")

        self._msl_version = msl_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AkamaiMslOutput, self), "to_dict"):
            result = super(AkamaiMslOutput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AkamaiMslOutput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class SimpleEncodingLiveJobStatus(Enum):
    CREATED = "CREATED"
    EXECUTING = "EXECUTING"
    FAILURE = "FAILURE"
    STARTING = "STARTING"
    RUNNING = "RUNNING"
    STOPPED = "STOPPED"
    ERROR = "ERROR"
    CANCELED = "CANCELED"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.dvb_teletext_input_stream import DvbTeletextInputStream
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.input_streams.subtitles.dvb_teletext.dvb_teletext_input_stream_list_query_params import DvbTeletextInputStreamListQueryParams


class DvbTeletextApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DvbTeletextApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, dvb_teletext_input_stream, **kwargs):
        # type: (string_types, DvbTeletextInputStream, dict) -> DvbTeletextInputStream
        """Add DVB-Teletext Input Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param dvb_teletext_input_stream: The DVB-Teletext Input Stream to be created
        :type dvb_teletext_input_stream: DvbTeletextInputStream, required
        :return: DVB-Teletext Input Stream
        :rtype: DvbTeletextInputStream
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/input-streams/subtitles/dvb-teletext',
            dvb_teletext_input_stream,
            path_params={'encoding_id': encoding_id},
            type=DvbTeletextInputStream,
            **kwargs
        )

    def delete(self, encoding_id, input_stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete DVB-Teletext Input Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param input_stream_id: Id of the DVB-Teletext input stream.
        :type input_stream_id: string_types, required
        :return: Id of the DVB-Teletext Input stream
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/input-streams/subtitles/dvb-teletext/{input_stream_id}',
            path_params={'encoding_id': encoding_id, 'input_stream_id': input_stream_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, input_stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> DvbTeletextInputStream
        """DVB-Teletext Input Stream Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param input_stream_id: Id of the DVB-Teletext input stream.
        :type input_stream_id: string_types, required
        :return: DVB-Teletext Input Stream
        :rtype: DvbTeletextInputStream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/input-streams/subtitles/dvb-teletext/{input_stream_id}',
            path_params={'encoding_id': encoding_id, 'input_stream_id': input_stream_id},
            type=DvbTeletextInputStream,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, DvbTeletextInputStreamListQueryParams, dict) -> DvbTeletextInputStream
        """List DVB-Teletext Input Streams

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: DvbTeletextInputStreamListQueryParams
        :return: List of DVB-Teletext Input Streams
        :rtype: DvbTeletextInputStream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/input-streams/subtitles/dvb-teletext',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=DvbTeletextInputStream,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ResourceType(Enum):
    ACCOUNT = "account"
    ENCODING = "encoding"
    PLAYER = "player"
    ANALYTICS = "analytics"



from bitmovin_api_sdk.notifications.emails.encoding.encodings.encodings_api import EncodingsApi
from bitmovin_api_sdk.notifications.emails.encoding.encodings.live_input_stream_changed.live_input_stream_changed_api import LiveInputStreamChangedApi
from bitmovin_api_sdk.notifications.emails.encoding.encodings.error.error_api import ErrorApi
from bitmovin_api_sdk.notifications.emails.encoding.encodings.email_notification_with_stream_conditions_list_query_params import EmailNotificationWithStreamConditionsListQueryParams



from bitmovin_api_sdk.encoding.inputs.sftp.sftp_api import SftpApi
from bitmovin_api_sdk.encoding.inputs.sftp.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.sftp.sftp_input_list_query_params import SftpInputListQueryParams



from bitmovin_api_sdk.encoding.configurations.audio.audio_api import AudioApi
from bitmovin_api_sdk.encoding.configurations.audio.aac.aac_api import AacApi
from bitmovin_api_sdk.encoding.configurations.audio.dts_passthrough.dts_passthrough_api import DtsPassthroughApi
from bitmovin_api_sdk.encoding.configurations.audio.dts.dts_api import DtsApi
from bitmovin_api_sdk.encoding.configurations.audio.dtsx.dtsx_api import DtsxApi
from bitmovin_api_sdk.encoding.configurations.audio.dolby_atmos.dolby_atmos_api import DolbyAtmosApi
from bitmovin_api_sdk.encoding.configurations.audio.he_aac_v1.he_aac_v1_api import HeAacV1Api
from bitmovin_api_sdk.encoding.configurations.audio.he_aac_v2.he_aac_v2_api import HeAacV2Api
from bitmovin_api_sdk.encoding.configurations.audio.vorbis.vorbis_api import VorbisApi
from bitmovin_api_sdk.encoding.configurations.audio.opus.opus_api import OpusApi
from bitmovin_api_sdk.encoding.configurations.audio.pcm.pcm_api import PcmApi
from bitmovin_api_sdk.encoding.configurations.audio.ac3.ac3_api import Ac3Api
from bitmovin_api_sdk.encoding.configurations.audio.dolby_digital.dolby_digital_api import DolbyDigitalApi
from bitmovin_api_sdk.encoding.configurations.audio.dolby_digital_plus.dolby_digital_plus_api import DolbyDigitalPlusApi
from bitmovin_api_sdk.encoding.configurations.audio.eac3.eac3_api import Eac3Api
from bitmovin_api_sdk.encoding.configurations.audio.mp2.mp2_api import Mp2Api
from bitmovin_api_sdk.encoding.configurations.audio.mp3.mp3_api import Mp3Api



from bitmovin_api_sdk.encoding.encodings.input_streams.trimming.time_based.time_based_api import TimeBasedApi
from bitmovin_api_sdk.encoding.encodings.input_streams.trimming.time_based.time_based_trimming_input_stream_list_query_params import TimeBasedTrimmingInputStreamListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dash_edition_compatibility import DashEditionCompatibility
from bitmovin_api_sdk.models.dash_profile import DashProfile
from bitmovin_api_sdk.models.manifest import Manifest
from bitmovin_api_sdk.models.manifest_type import ManifestType
from bitmovin_api_sdk.models.status import Status
import pprint
import six


class DashManifest(Manifest):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 type_=None,
                 outputs=None,
                 status=None,
                 profile=None,
                 manifest_name=None,
                 namespaces=None,
                 utc_timings=None,
                 dash_edition_compatibility=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, ManifestType, list[EncodingOutput], Status, DashProfile, string_types, list[XmlNamespace], list[UtcTiming], DashEditionCompatibility) -> None
        super(DashManifest, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, type_=type_, outputs=outputs, status=status)

        self._profile = None
        self._manifest_name = None
        self._namespaces = list()
        self._utc_timings = list()
        self._dash_edition_compatibility = None
        self.discriminator = None

        if profile is not None:
            self.profile = profile
        if manifest_name is not None:
            self.manifest_name = manifest_name
        if namespaces is not None:
            self.namespaces = namespaces
        if utc_timings is not None:
            self.utc_timings = utc_timings
        if dash_edition_compatibility is not None:
            self.dash_edition_compatibility = dash_edition_compatibility

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(DashManifest, self), 'openapi_types'):
            types = getattr(super(DashManifest, self), 'openapi_types')

        types.update({
            'profile': 'DashProfile',
            'manifest_name': 'string_types',
            'namespaces': 'list[XmlNamespace]',
            'utc_timings': 'list[UtcTiming]',
            'dash_edition_compatibility': 'DashEditionCompatibility'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(DashManifest, self), 'attribute_map'):
            attributes = getattr(super(DashManifest, self), 'attribute_map')

        attributes.update({
            'profile': 'profile',
            'manifest_name': 'manifestName',
            'namespaces': 'namespaces',
            'utc_timings': 'utcTimings',
            'dash_edition_compatibility': 'dashEditionCompatibility'
        })
        return attributes

    @property
    def profile(self):
        # type: () -> DashProfile
        """Gets the profile of this DashManifest.

        Determines if segmented or progressive representations can appear in the manifest

        :return: The profile of this DashManifest.
        :rtype: DashProfile
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        # type: (DashProfile) -> None
        """Sets the profile of this DashManifest.

        Determines if segmented or progressive representations can appear in the manifest

        :param profile: The profile of this DashManifest.
        :type: DashProfile
        """

        if profile is not None:
            if not isinstance(profile, DashProfile):
                raise TypeError("Invalid type for `profile`, type has to be `DashProfile`")

        self._profile = profile

    @property
    def manifest_name(self):
        # type: () -> string_types
        """Gets the manifest_name of this DashManifest.

        The filename of your manifest

        :return: The manifest_name of this DashManifest.
        :rtype: string_types
        """
        return self._manifest_name

    @manifest_name.setter
    def manifest_name(self, manifest_name):
        # type: (string_types) -> None
        """Sets the manifest_name of this DashManifest.

        The filename of your manifest

        :param manifest_name: The manifest_name of this DashManifest.
        :type: string_types
        """

        if manifest_name is not None:
            if not isinstance(manifest_name, string_types):
                raise TypeError("Invalid type for `manifest_name`, type has to be `string_types`")

        self._manifest_name = manifest_name

    @property
    def namespaces(self):
        # type: () -> list[XmlNamespace]
        """Gets the namespaces of this DashManifest.

        List of additional XML namespaces to add to the DASH Manifest

        :return: The namespaces of this DashManifest.
        :rtype: list[XmlNamespace]
        """
        return self._namespaces

    @namespaces.setter
    def namespaces(self, namespaces):
        # type: (list) -> None
        """Sets the namespaces of this DashManifest.

        List of additional XML namespaces to add to the DASH Manifest

        :param namespaces: The namespaces of this DashManifest.
        :type: list[XmlNamespace]
        """

        if namespaces is not None:
            if not isinstance(namespaces, list):
                raise TypeError("Invalid type for `namespaces`, type has to be `list[XmlNamespace]`")

        self._namespaces = namespaces

    @property
    def utc_timings(self):
        # type: () -> list[UtcTiming]
        """Gets the utc_timings of this DashManifest.

        List of UTC Timings to use for live streaming

        :return: The utc_timings of this DashManifest.
        :rtype: list[UtcTiming]
        """
        return self._utc_timings

    @utc_timings.setter
    def utc_timings(self, utc_timings):
        # type: (list) -> None
        """Sets the utc_timings of this DashManifest.

        List of UTC Timings to use for live streaming

        :param utc_timings: The utc_timings of this DashManifest.
        :type: list[UtcTiming]
        """

        if utc_timings is not None:
            if not isinstance(utc_timings, list):
                raise TypeError("Invalid type for `utc_timings`, type has to be `list[UtcTiming]`")

        self._utc_timings = utc_timings

    @property
    def dash_edition_compatibility(self):
        # type: () -> DashEditionCompatibility
        """Gets the dash_edition_compatibility of this DashManifest.

        The manifest compatibility with the standard DASH Edition.

        :return: The dash_edition_compatibility of this DashManifest.
        :rtype: DashEditionCompatibility
        """
        return self._dash_edition_compatibility

    @dash_edition_compatibility.setter
    def dash_edition_compatibility(self, dash_edition_compatibility):
        # type: (DashEditionCompatibility) -> None
        """Sets the dash_edition_compatibility of this DashManifest.

        The manifest compatibility with the standard DASH Edition.

        :param dash_edition_compatibility: The dash_edition_compatibility of this DashManifest.
        :type: DashEditionCompatibility
        """

        if dash_edition_compatibility is not None:
            if not isinstance(dash_edition_compatibility, DashEditionCompatibility):
                raise TypeError("Invalid type for `dash_edition_compatibility`, type has to be `DashEditionCompatibility`")

        self._dash_edition_compatibility = dash_edition_compatibility

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(DashManifest, self), "to_dict"):
            result = super(DashManifest, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashManifest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AnalyticsQueryTimeframe(object):
    @poscheck_model
    def __init__(self,
                 start=None,
                 end=None):
        # type: (datetime, datetime) -> None

        self._start = None
        self._end = None
        self.discriminator = None

        if start is not None:
            self.start = start
        if end is not None:
            self.end = end

    @property
    def openapi_types(self):
        types = {
            'start': 'datetime',
            'end': 'datetime'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'start': 'start',
            'end': 'end'
        }
        return attributes

    @property
    def start(self):
        # type: () -> datetime
        """Gets the start of this AnalyticsQueryTimeframe.

        Start of timeframe which is queried in UTC format.

        :return: The start of this AnalyticsQueryTimeframe.
        :rtype: datetime
        """
        return self._start

    @start.setter
    def start(self, start):
        # type: (datetime) -> None
        """Sets the start of this AnalyticsQueryTimeframe.

        Start of timeframe which is queried in UTC format.

        :param start: The start of this AnalyticsQueryTimeframe.
        :type: datetime
        """

        if start is not None:
            if not isinstance(start, datetime):
                raise TypeError("Invalid type for `start`, type has to be `datetime`")

        self._start = start

    @property
    def end(self):
        # type: () -> datetime
        """Gets the end of this AnalyticsQueryTimeframe.

        End of timeframe which is queried in UTC format.

        :return: The end of this AnalyticsQueryTimeframe.
        :rtype: datetime
        """
        return self._end

    @end.setter
    def end(self, end):
        # type: (datetime) -> None
        """Sets the end of this AnalyticsQueryTimeframe.

        End of timeframe which is queried in UTC format.

        :param end: The end of this AnalyticsQueryTimeframe.
        :type: datetime
        """

        if end is not None:
            if not isinstance(end, datetime):
                raise TypeError("Invalid type for `end`, type has to be `datetime`")

        self._end = end

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsQueryTimeframe):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.widevine.widevine_api import WidevineApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.widevine.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.widevine.widevine_drm_list_query_params import WidevineDrmListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class SimpleEncodingVodJobOptions(object):
    @poscheck_model
    def __init__(self,
                 single_file_output=None):
        # type: (bool) -> None

        self._single_file_output = None
        self.discriminator = None

        if single_file_output is not None:
            self.single_file_output = single_file_output

    @property
    def openapi_types(self):
        types = {
            'single_file_output': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'single_file_output': 'singleFileOutput'
        }
        return attributes

    @property
    def single_file_output(self):
        # type: () -> bool
        """Gets the single_file_output of this SimpleEncodingVodJobOptions.

        Defines if the job should additionally produce a single file as output (e.g., an MP4) for every rendition the Per-Title algorithm produces. This can be useful to provide customers with features such as downloading of videos for different screen sizes.  The single file contains both audio and video streams along the segmented output. Note that currently we do not include subtitles in this file. 

        :return: The single_file_output of this SimpleEncodingVodJobOptions.
        :rtype: bool
        """
        return self._single_file_output

    @single_file_output.setter
    def single_file_output(self, single_file_output):
        # type: (bool) -> None
        """Sets the single_file_output of this SimpleEncodingVodJobOptions.

        Defines if the job should additionally produce a single file as output (e.g., an MP4) for every rendition the Per-Title algorithm produces. This can be useful to provide customers with features such as downloading of videos for different screen sizes.  The single file contains both audio and video streams along the segmented output. Note that currently we do not include subtitles in this file. 

        :param single_file_output: The single_file_output of this SimpleEncodingVodJobOptions.
        :type: bool
        """

        if single_file_output is not None:
            if not isinstance(single_file_output, bool):
                raise TypeError("Invalid type for `single_file_output`, type has to be `bool`")

        self._single_file_output = single_file_output

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimpleEncodingVodJobOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint
import six


class PlayerLicense(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 created_at=None,
                 license_key=None,
                 impressions=None,
                 max_impressions=None,
                 third_party_licensing_enabled=None,
                 domains=None,
                 analytics_key=None):
        # type: (string_types, string_types, datetime, string_types, int, int, bool, list[Domain], string_types) -> None
        super(PlayerLicense, self).__init__(id_=id_)

        self._name = None
        self._created_at = None
        self._license_key = None
        self._impressions = None
        self._max_impressions = None
        self._third_party_licensing_enabled = None
        self._domains = list()
        self._analytics_key = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if created_at is not None:
            self.created_at = created_at
        if license_key is not None:
            self.license_key = license_key
        if impressions is not None:
            self.impressions = impressions
        if max_impressions is not None:
            self.max_impressions = max_impressions
        if third_party_licensing_enabled is not None:
            self.third_party_licensing_enabled = third_party_licensing_enabled
        if domains is not None:
            self.domains = domains
        if analytics_key is not None:
            self.analytics_key = analytics_key

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(PlayerLicense, self), 'openapi_types'):
            types = getattr(super(PlayerLicense, self), 'openapi_types')

        types.update({
            'name': 'string_types',
            'created_at': 'datetime',
            'license_key': 'string_types',
            'impressions': 'int',
            'max_impressions': 'int',
            'third_party_licensing_enabled': 'bool',
            'domains': 'list[Domain]',
            'analytics_key': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(PlayerLicense, self), 'attribute_map'):
            attributes = getattr(super(PlayerLicense, self), 'attribute_map')

        attributes.update({
            'name': 'name',
            'created_at': 'createdAt',
            'license_key': 'licenseKey',
            'impressions': 'impressions',
            'max_impressions': 'maxImpressions',
            'third_party_licensing_enabled': 'thirdPartyLicensingEnabled',
            'domains': 'domains',
            'analytics_key': 'analyticsKey'
        })
        return attributes

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this PlayerLicense.

        Name of the resource (required)

        :return: The name of this PlayerLicense.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this PlayerLicense.

        Name of the resource (required)

        :param name: The name of this PlayerLicense.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this PlayerLicense.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ (required)

        :return: The created_at of this PlayerLicense.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (datetime) -> None
        """Sets the created_at of this PlayerLicense.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ (required)

        :param created_at: The created_at of this PlayerLicense.
        :type: datetime
        """

        if created_at is not None:
            if not isinstance(created_at, datetime):
                raise TypeError("Invalid type for `created_at`, type has to be `datetime`")

        self._created_at = created_at

    @property
    def license_key(self):
        # type: () -> string_types
        """Gets the license_key of this PlayerLicense.

        License Key (required)

        :return: The license_key of this PlayerLicense.
        :rtype: string_types
        """
        return self._license_key

    @license_key.setter
    def license_key(self, license_key):
        # type: (string_types) -> None
        """Sets the license_key of this PlayerLicense.

        License Key (required)

        :param license_key: The license_key of this PlayerLicense.
        :type: string_types
        """

        if license_key is not None:
            if not isinstance(license_key, string_types):
                raise TypeError("Invalid type for `license_key`, type has to be `string_types`")

        self._license_key = license_key

    @property
    def impressions(self):
        # type: () -> int
        """Gets the impressions of this PlayerLicense.

        Number of impressions recorded (required)

        :return: The impressions of this PlayerLicense.
        :rtype: int
        """
        return self._impressions

    @impressions.setter
    def impressions(self, impressions):
        # type: (int) -> None
        """Sets the impressions of this PlayerLicense.

        Number of impressions recorded (required)

        :param impressions: The impressions of this PlayerLicense.
        :type: int
        """

        if impressions is not None:
            if not isinstance(impressions, int):
                raise TypeError("Invalid type for `impressions`, type has to be `int`")

        self._impressions = impressions

    @property
    def max_impressions(self):
        # type: () -> int
        """Gets the max_impressions of this PlayerLicense.

        Maximum number of impressions (required)

        :return: The max_impressions of this PlayerLicense.
        :rtype: int
        """
        return self._max_impressions

    @max_impressions.setter
    def max_impressions(self, max_impressions):
        # type: (int) -> None
        """Sets the max_impressions of this PlayerLicense.

        Maximum number of impressions (required)

        :param max_impressions: The max_impressions of this PlayerLicense.
        :type: int
        """

        if max_impressions is not None:
            if not isinstance(max_impressions, int):
                raise TypeError("Invalid type for `max_impressions`, type has to be `int`")

        self._max_impressions = max_impressions

    @property
    def third_party_licensing_enabled(self):
        # type: () -> bool
        """Gets the third_party_licensing_enabled of this PlayerLicense.

        Flag if third party licensing is enabled (required)

        :return: The third_party_licensing_enabled of this PlayerLicense.
        :rtype: bool
        """
        return self._third_party_licensing_enabled

    @third_party_licensing_enabled.setter
    def third_party_licensing_enabled(self, third_party_licensing_enabled):
        # type: (bool) -> None
        """Sets the third_party_licensing_enabled of this PlayerLicense.

        Flag if third party licensing is enabled (required)

        :param third_party_licensing_enabled: The third_party_licensing_enabled of this PlayerLicense.
        :type: bool
        """

        if third_party_licensing_enabled is not None:
            if not isinstance(third_party_licensing_enabled, bool):
                raise TypeError("Invalid type for `third_party_licensing_enabled`, type has to be `bool`")

        self._third_party_licensing_enabled = third_party_licensing_enabled

    @property
    def domains(self):
        # type: () -> list[Domain]
        """Gets the domains of this PlayerLicense.

        Whitelisted domains (required)

        :return: The domains of this PlayerLicense.
        :rtype: list[Domain]
        """
        return self._domains

    @domains.setter
    def domains(self, domains):
        # type: (list) -> None
        """Sets the domains of this PlayerLicense.

        Whitelisted domains (required)

        :param domains: The domains of this PlayerLicense.
        :type: list[Domain]
        """

        if domains is not None:
            if not isinstance(domains, list):
                raise TypeError("Invalid type for `domains`, type has to be `list[Domain]`")

        self._domains = domains

    @property
    def analytics_key(self):
        # type: () -> string_types
        """Gets the analytics_key of this PlayerLicense.

        Analytics License Key

        :return: The analytics_key of this PlayerLicense.
        :rtype: string_types
        """
        return self._analytics_key

    @analytics_key.setter
    def analytics_key(self, analytics_key):
        # type: (string_types) -> None
        """Sets the analytics_key of this PlayerLicense.

        Analytics License Key

        :param analytics_key: The analytics_key of this PlayerLicense.
        :type: string_types
        """

        if analytics_key is not None:
            if not isinstance(analytics_key, string_types):
                raise TypeError("Invalid type for `analytics_key`, type has to be `string_types`")

        self._analytics_key = analytics_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(PlayerLicense, self), "to_dict"):
            result = super(PlayerLicense, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayerLicense):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.live_options_summary import LiveOptionsSummary
import pprint
import six


class LiveOptionsStatistics(object):
    @poscheck_model
    def __init__(self,
                 summary=None,
                 breakdown=None):
        # type: (LiveOptionsSummary, list[LiveOptionsBreakdownEntry]) -> None

        self._summary = None
        self._breakdown = list()
        self.discriminator = None

        if summary is not None:
            self.summary = summary
        if breakdown is not None:
            self.breakdown = breakdown

    @property
    def openapi_types(self):
        types = {
            'summary': 'LiveOptionsSummary',
            'breakdown': 'list[LiveOptionsBreakdownEntry]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'summary': 'summary',
            'breakdown': 'breakdown'
        }
        return attributes

    @property
    def summary(self):
        # type: () -> LiveOptionsSummary
        """Gets the summary of this LiveOptionsStatistics.


        :return: The summary of this LiveOptionsStatistics.
        :rtype: LiveOptionsSummary
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        # type: (LiveOptionsSummary) -> None
        """Sets the summary of this LiveOptionsStatistics.


        :param summary: The summary of this LiveOptionsStatistics.
        :type: LiveOptionsSummary
        """

        if summary is not None:
            if not isinstance(summary, LiveOptionsSummary):
                raise TypeError("Invalid type for `summary`, type has to be `LiveOptionsSummary`")

        self._summary = summary

    @property
    def breakdown(self):
        # type: () -> list[LiveOptionsBreakdownEntry]
        """Gets the breakdown of this LiveOptionsStatistics.

        Live options statistics aggregated per day (required)

        :return: The breakdown of this LiveOptionsStatistics.
        :rtype: list[LiveOptionsBreakdownEntry]
        """
        return self._breakdown

    @breakdown.setter
    def breakdown(self, breakdown):
        # type: (list) -> None
        """Sets the breakdown of this LiveOptionsStatistics.

        Live options statistics aggregated per day (required)

        :param breakdown: The breakdown of this LiveOptionsStatistics.
        :type: list[LiveOptionsBreakdownEntry]
        """

        if breakdown is not None:
            if not isinstance(breakdown, list):
                raise TypeError("Invalid type for `breakdown`, type has to be `list[LiveOptionsBreakdownEntry]`")

        self._breakdown = breakdown

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveOptionsStatistics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



class PositionalArgumentsError(Exception):
    def __init__(self, f, n, message=None):
        super(PositionalArgumentsError, self).__init__()
        self.f = f
        self.n = n
        self.message = message

    def __str__(self):
        if self.n == 0:
            return "%s takes only keyword arguments" % self.f.__name__
        elif self.message:
            return self.message
        else:
            return 'all arguments to %s after the first %s must be keyword arguments' % (self.f.__name__, self.n)


def poscheck(f):
    return poscheck_except(0)(f)


def poscheck_model(f):
    error_message = """Models cannot be initialized using positional arguments. Use keyword arguments instead.

    Example:

    Wrong:
    encoding = Encoding('my encoding name', 'my encoding description')

    Correct:
    encoding = Encoding(name='my encoding name', description='my encoding description')
    """
    return poscheck_except(1, message=error_message)(f)


def poscheck_except(n, message=None):
    def helper(f):
        def checked_f(*args, **kwargs):
            if len(args) > n:
                if message:
                    raise PositionalArgumentsError(f, n, message=message)
                else:
                    raise PositionalArgumentsError(f, n)
            return f(*args, **kwargs)
        return checked_f
    return helper



from bitmovin_api_sdk.encoding.manifests.hls.media.vtt.vtt_api import VttApi
from bitmovin_api_sdk.encoding.manifests.hls.media.vtt.vtt_media_info_list_query_params import VttMediaInfoListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.stream_info import StreamInfo
from bitmovin_api_sdk.encoding.manifests.hls.streams.custom_tags.custom_tags_api import CustomTagsApi
from bitmovin_api_sdk.encoding.manifests.hls.streams.iframe.iframe_api import IframeApi
from bitmovin_api_sdk.encoding.manifests.hls.streams.stream_info_list_query_params import StreamInfoListQueryParams


class StreamsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(StreamsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.custom_tags = CustomTagsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.iframe = IframeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, manifest_id, stream_info, **kwargs):
        # type: (string_types, StreamInfo, dict) -> StreamInfo
        """Add Variant Stream

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param stream_info: The Variant Stream to be added
        :type stream_info: StreamInfo, required
        :return: Variant stream details
        :rtype: StreamInfo
        """

        return self.api_client.post(
            '/encoding/manifests/hls/{manifest_id}/streams',
            stream_info,
            path_params={'manifest_id': manifest_id},
            type=StreamInfo,
            **kwargs
        )

    def delete(self, manifest_id, stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Variant Stream

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param stream_id: Id of the variant stream.
        :type stream_id: string_types, required
        :return: Id of the stream inf
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/hls/{manifest_id}/streams/{stream_id}',
            path_params={'manifest_id': manifest_id, 'stream_id': stream_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> StreamInfo
        """Variant Stream Details

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param stream_id: Id of the variant stream.
        :type stream_id: string_types, required
        :return: Variant stream details
        :rtype: StreamInfo
        """

        return self.api_client.get(
            '/encoding/manifests/hls/{manifest_id}/streams/{stream_id}',
            path_params={'manifest_id': manifest_id, 'stream_id': stream_id},
            type=StreamInfo,
            **kwargs
        )

    def list(self, manifest_id, query_params=None, **kwargs):
        # type: (string_types, StreamInfoListQueryParams, dict) -> StreamInfo
        """List all Variant Streams

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param query_params: Query parameters
        :type query_params: StreamInfoListQueryParams
        :return: Variant streams
        :rtype: StreamInfo
        """

        return self.api_client.get(
            '/encoding/manifests/hls/{manifest_id}/streams',
            path_params={'manifest_id': manifest_id},
            query_params=query_params,
            pagination_response=True,
            type=StreamInfo,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class StreamsVideoStatus(Enum):
    PUBLISHED = "PUBLISHED"
    UNPUBLISHED = "UNPUBLISHED"



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.scheduled_insertable_content_status import ScheduledInsertableContentStatus
import pprint
import six


class ScheduledInsertableContent(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 content_id=None,
                 run_at=None,
                 duration_in_seconds=None,
                 status=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, datetime, float, ScheduledInsertableContentStatus) -> None
        super(ScheduledInsertableContent, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._content_id = None
        self._run_at = None
        self._duration_in_seconds = None
        self._status = None
        self.discriminator = None

        if content_id is not None:
            self.content_id = content_id
        if run_at is not None:
            self.run_at = run_at
        if duration_in_seconds is not None:
            self.duration_in_seconds = duration_in_seconds
        if status is not None:
            self.status = status

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(ScheduledInsertableContent, self), 'openapi_types'):
            types = getattr(super(ScheduledInsertableContent, self), 'openapi_types')

        types.update({
            'content_id': 'string_types',
            'run_at': 'datetime',
            'duration_in_seconds': 'float',
            'status': 'ScheduledInsertableContentStatus'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(ScheduledInsertableContent, self), 'attribute_map'):
            attributes = getattr(super(ScheduledInsertableContent, self), 'attribute_map')

        attributes.update({
            'content_id': 'contentId',
            'run_at': 'runAt',
            'duration_in_seconds': 'durationInSeconds',
            'status': 'status'
        })
        return attributes

    @property
    def content_id(self):
        # type: () -> string_types
        """Gets the content_id of this ScheduledInsertableContent.

        Id of the insertable content to play instead of the live stream

        :return: The content_id of this ScheduledInsertableContent.
        :rtype: string_types
        """
        return self._content_id

    @content_id.setter
    def content_id(self, content_id):
        # type: (string_types) -> None
        """Sets the content_id of this ScheduledInsertableContent.

        Id of the insertable content to play instead of the live stream

        :param content_id: The content_id of this ScheduledInsertableContent.
        :type: string_types
        """

        if content_id is not None:
            if not isinstance(content_id, string_types):
                raise TypeError("Invalid type for `content_id`, type has to be `string_types`")

        self._content_id = content_id

    @property
    def run_at(self):
        # type: () -> datetime
        """Gets the run_at of this ScheduledInsertableContent.

        Time to play the content in UTC: YYYY-MM-DDThh:mm:ssZ, if this property is not set the content will be played as soon as possible.

        :return: The run_at of this ScheduledInsertableContent.
        :rtype: datetime
        """
        return self._run_at

    @run_at.setter
    def run_at(self, run_at):
        # type: (datetime) -> None
        """Sets the run_at of this ScheduledInsertableContent.

        Time to play the content in UTC: YYYY-MM-DDThh:mm:ssZ, if this property is not set the content will be played as soon as possible.

        :param run_at: The run_at of this ScheduledInsertableContent.
        :type: datetime
        """

        if run_at is not None:
            if not isinstance(run_at, datetime):
                raise TypeError("Invalid type for `run_at`, type has to be `datetime`")

        self._run_at = run_at

    @property
    def duration_in_seconds(self):
        # type: () -> float
        """Gets the duration_in_seconds of this ScheduledInsertableContent.

        Duration for how long to play the content. Cut off if shorter, loop if longer than actual duration. This property is required if the insertable content is an image.

        :return: The duration_in_seconds of this ScheduledInsertableContent.
        :rtype: float
        """
        return self._duration_in_seconds

    @duration_in_seconds.setter
    def duration_in_seconds(self, duration_in_seconds):
        # type: (float) -> None
        """Sets the duration_in_seconds of this ScheduledInsertableContent.

        Duration for how long to play the content. Cut off if shorter, loop if longer than actual duration. This property is required if the insertable content is an image.

        :param duration_in_seconds: The duration_in_seconds of this ScheduledInsertableContent.
        :type: float
        """

        if duration_in_seconds is not None:
            if not isinstance(duration_in_seconds, (float, int)):
                raise TypeError("Invalid type for `duration_in_seconds`, type has to be `float`")

        self._duration_in_seconds = duration_in_seconds

    @property
    def status(self):
        # type: () -> ScheduledInsertableContentStatus
        """Gets the status of this ScheduledInsertableContent.

        Status of the scheduled insertable content.

        :return: The status of this ScheduledInsertableContent.
        :rtype: ScheduledInsertableContentStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (ScheduledInsertableContentStatus) -> None
        """Sets the status of this ScheduledInsertableContent.

        Status of the scheduled insertable content.

        :param status: The status of this ScheduledInsertableContent.
        :type: ScheduledInsertableContentStatus
        """

        if status is not None:
            if not isinstance(status, ScheduledInsertableContentStatus):
                raise TypeError("Invalid type for `status`, type has to be `ScheduledInsertableContentStatus`")

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(ScheduledInsertableContent, self), "to_dict"):
            result = super(ScheduledInsertableContent, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScheduledInsertableContent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.enhanced_deinterlace_filter import EnhancedDeinterlaceFilter
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.filters.enhanced_deinterlace.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.enhanced_deinterlace.enhanced_deinterlace_filter_list_query_params import EnhancedDeinterlaceFilterListQueryParams


class EnhancedDeinterlaceApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(EnhancedDeinterlaceApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, enhanced_deinterlace_filter, **kwargs):
        # type: (EnhancedDeinterlaceFilter, dict) -> EnhancedDeinterlaceFilter
        """Create Enhanced Deinterlace Filter

        :param enhanced_deinterlace_filter: The Enhanced Deinterlace Filter to be created
        :type enhanced_deinterlace_filter: EnhancedDeinterlaceFilter, required
        :return: Enhanced Deinterlace Filter details
        :rtype: EnhancedDeinterlaceFilter
        """

        return self.api_client.post(
            '/encoding/filters/enhanced-deinterlace',
            enhanced_deinterlace_filter,
            type=EnhancedDeinterlaceFilter,
            **kwargs
        )

    def delete(self, filter_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Enhanced Deinterlace Filter

        :param filter_id: Id of the Enhanced Deinterlace Filter
        :type filter_id: string_types, required
        :return: Id of the Enhanced Deinterlace Filter.
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/filters/enhanced-deinterlace/{filter_id}',
            path_params={'filter_id': filter_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, filter_id, **kwargs):
        # type: (string_types, dict) -> EnhancedDeinterlaceFilter
        """Enhanced Deinterlace Filter Details

        :param filter_id: Id of the Enhanced Deinterlace Filter
        :type filter_id: string_types, required
        :return: Enhanced Deinterlace Filter details
        :rtype: EnhancedDeinterlaceFilter
        """

        return self.api_client.get(
            '/encoding/filters/enhanced-deinterlace/{filter_id}',
            path_params={'filter_id': filter_id},
            type=EnhancedDeinterlaceFilter,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (EnhancedDeinterlaceFilterListQueryParams, dict) -> EnhancedDeinterlaceFilter
        """List Enhanced Deinterlace Filters

        :param query_params: Query parameters
        :type query_params: EnhancedDeinterlaceFilterListQueryParams
        :return: List of Enhanced Deinterlace Filters
        :rtype: EnhancedDeinterlaceFilter
        """

        return self.api_client.get(
            '/encoding/filters/enhanced-deinterlace',
            query_params=query_params,
            pagination_response=True,
            type=EnhancedDeinterlaceFilter,
            **kwargs
        )



from bitmovin_api_sdk.analytics.outputs.s3_role_based.s3_role_based_api import S3RoleBasedApi
from bitmovin_api_sdk.analytics.outputs.s3_role_based.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.analytics.outputs.s3_role_based.analytics_s3_role_based_output_list_query_params import AnalyticsS3RoleBasedOutputListQueryParams
